@@ -1,4 +1,6 @@
-# Copyright 2010 OpenStack Foundation
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
+# Copyright 2010 OpenStack LLC.
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -13,19 +15,27 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import six
-
-from keystoneclient.generic import client
-from keystoneclient.i18n import _
 from keystoneclient import utils
-
+from keystoneclient.generic import client
 
 CLIENT_CLASS = client.Client
 
 
 @utils.unauthenticated
 def do_discover(cs, args):
-    """Discover Keystone servers, supported API versions and extensions."""
+    """
+    Discover Keystone servers and show authentication protocols and
+    extensions supported.
+
+    Usage::
+    $ keystone discover
+    Keystone found at http://localhost:35357
+        - supports version v1.0 (DEPRECATED) here http://localhost:35357/v1.0
+        - supports version v1.1 (CURRENT) here http://localhost:35357/v1.1
+        - supports version v2.0 (BETA) here http://localhost:35357/v2.0
+            - and RAX-KSKEY: Rackspace API Key Authentication Admin Extension
+            - and RAX-KSGRP: Rackspace Keystone Group Extensions
+    """
     if cs.endpoint:
         versions = cs.discover(cs.endpoint)
     elif cs.auth_url:
@@ -34,17 +44,16 @@ def do_discover(cs, args):
         versions = cs.discover()
     if versions:
         if 'message' in versions:
-            print(versions['message'])
-        for key, version in six.iteritems(versions):
+            print versions['message']
+        for key, version in versions.iteritems():
             if key != 'message':
-                print(_("    - supports version %(id)s (%(status)s) here "
-                        "%(url)s") %
-                      version)
+                print ("    - supports version %s (%s) here %s" %
+                       (version['id'], version['status'], version['url']))
                 extensions = cs.discover_extensions(version['url'])
                 if extensions:
-                    for key, extension in six.iteritems(extensions):
+                    for key, extension in extensions.iteritems():
                         if key != 'message':
-                            print(_("        - and %(key)s: %(extension)s") %
-                                  {'key': key, 'extension': extension})
+                            print ("        - and %s: %s" %
+                                   (key, extension))
     else:
-        print(_("No Keystone-compatible endpoint found"))
+        print "No Keystone-compatible endpoint found"
