@@ -1,4 +1,4 @@
-# Copyright 2011 OpenStack Foundation
+# Copyright 2011 OpenStack LLC.
 # Copyright 2011 Nebula, Inc.
 # All Rights Reserved.
 #
@@ -18,30 +18,24 @@ from keystoneclient import base
 
 
 class Service(base.Resource):
-    """Represents a Keystone service."""
     def __repr__(self):
         return "<Service %s>" % self._info
 
 
 class ServiceManager(base.ManagerWithFind):
-    """Manager class for manipulating Keystone services."""
     resource_class = Service
 
     def list(self):
-        """List available services."""
         return self._list("/OS-KSADM/services", "OS-KSADM:services")
 
     def get(self, id):
-        """Retrieve a service by id."""
         return self._get("/OS-KSADM/services/%s" % id, "OS-KSADM:service")
 
-    def create(self, name, service_type, description=None):
-        """Create a new service."""
+    def create(self, name, service_type, description):
         body = {"OS-KSADM:service": {'name': name,
                                      'type': service_type,
                                      'description': description}}
-        return self._post("/OS-KSADM/services", body, "OS-KSADM:service")
+        return self._create("/OS-KSADM/services", body, "OS-KSADM:service")
 
     def delete(self, id):
-        """Delete a service."""
         return self._delete("/OS-KSADM/services/%s" % id)
